import { login, logout, getInfo } from '@/api/user';
import { getToken, setToken, removeToken } from '@/utils/auth';
import { getAuthToken, setAuthToken, removeAuthToken } from '@/utils/auth-token';
import APPId from '@/utils/appId'
import { resetRouter } from '@/router'

const getDefaultState = () => {
  return {
    token: getToken(),
    authToken: getAuthToken(),
    name: '',
    avatar: ''
  }
}

const state = getDefaultState()

const mutations = {
  RESET_STATE: (state) => {
    Object.assign(state, getDefaultState())
  },
  SET_TOKEN: (state, token) => {
    state.token = token
  },
  SET_AUTH_TOKEN: (state, authToken) => {
    state.authToken = authToken
  },
  SET_NAME: (state, name) => {
    state.name = name
  },
  SET_AVATAR: (state, avatar) => {
    state.avatar = avatar
  },
  SET_ROLES: (state, roles) => {
    state.roles = roles
  }
}

const actions = {
  // user login
  login({ commit }, userInfo) {
    const { loginName, password } = userInfo
    return new Promise((resolve, reject) => {
      login({ loginName: loginName.trim(), password: password, appId: APPId }).then(response => {
        console.log("response", response);
        const { data } = response;
        commit('SET_TOKEN', data.authToken);
        setToken(data.authToken)
        resolve(data)
      }).catch(error => {
        reject(error)
      })
    })
  },
  // get user info
  getInfo({ commit}) {
    return new Promise((resolve, reject) => {
     let manufactorId = '5bf13062-a41e-4d00-ba14-1101aad12650'
      getInfo({manufactorId: manufactorId}).then(response => {
        const { data } = response;
        /* data['roles'] = ['admin'] */
        if (!data) {
          return reject('验证过期,请重新登录!')
        }
        /* const { roles, name} = data
        commit('SET_ROLES', roles)
        commit('SET_NAME', name) */
        commit('SET_AUTH_TOKEN', data);
        setAuthToken(data);
        resolve(data)
      }).catch(error => {
        reject(error)
      })
    })
  },

  // user logout
  logout({ commit, state }) {
    return new Promise((resolve, reject) => {
      logout(state.token).then(() => {
        removeToken() // must remove  token  first
        resetRouter()
        commit('RESET_STATE')
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },

  // remove token
  resetToken({ commit, state }) {
    return new Promise(resolve => {
      removeToken() // must remove  token  first
      commit('RESET_STATE')
      resolve()
    })
  },
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}

